@@ -10,16 +10,17 @@ NULL
 #' @param first_row row corresponding the first day of time interval where montlhy mean conservation is applied
 #' @param last_row corresponding the last day of time interval where montlhy mean conservation is applied
 #' @param no_spline logical value. If \code{TRUE} no spline interpolation is calculated and the daily value corresponds to the monthly averaga value. Default is \code{FALSE}.
-#' @export 
+#' @param no_mean logical value. If \code{TRUE} output is not rescaled with mean monthly values
+#'  @export 
 #'  
-#' @return a matrix with interpolated daily data 
+#' @return a matrix or data frame with interpolated daily data 
 #' 
 #' @seealso \code{\link{spline}},\code{\link{splineInterpolateMonthlytoDailyforSeveralYears}}
 #' 
 #' @author Emanuele Cordano, Emanuele Eccel
 
 splineInterpolateMonthlytoDaily <-
-function(nday=365,val=as.matrix(cbind(1*(0.5:11.5)*nday/12,2*(0.5:11.5)*nday/12)),origin="1961-1-1",first_row=1,last_row=nday,no_spline=FALSE) {
+function(nday=365,val=as.matrix(cbind(1*(0.5:11.5)*nday/12,2*(0.5:11.5)*nday/12)),origin="1961-1-1",first_row=1,last_row=nday,no_spline=FALSE,no_mean=FALSE) {
 	
 	nmonth=nrow(val)
 	
@@ -52,12 +53,15 @@ function(nday=365,val=as.matrix(cbind(1*(0.5:11.5)*nday/12,2*(0.5:11.5)*nday/12)
 		for (m in 1:length(months)) {
 			
 			i_months <- extractmonths(data=1:length(out2),when=months[m],origin=origin)
-
+			
+			
 			
 			if (no_spline) {
 				out2[i_months[i_months %in% first_row:last_row]] <-  val[m,i]
-			} else {
+			} else if (!no_mean){
 				out2[i_months[i_months %in% first_row:last_row]] <-  out1[i_months[i_months %in% first_row:last_row]]-mean(out1[i_months[i_months %in% first_row:last_row]])+val[m,i] 
+			} else {
+				out2[i_months[i_months %in% first_row:last_row]] <-  out1[i_months[i_months %in% first_row:last_row]]
 			}
 	 	}	
 #		for (m in 1:nmonth) {
